==> node-millstone_0.3.0.orig.tar.gz: package/lib/util.js <==
var fs = require('fs'),
    path = require('path'),
    _ = require('underscore'),
    Step = require('step');

// https://gist.github.com/707661
function mkdirP(p, mode, f) {
    var cb = f || function() {};
    if (p.charAt(0) != '/') {
        cb(new Error('Relative path: ' + p));
        return;
    }

    var ps = path.normalize(p).split('/');
    path.exists(p, function(exists) {
        if (exists) cb(null);
        else mkdirP(ps.slice(0, -1).join('/'), mode, function(err) {
            if (err && err.code !== 'EEXIST') cb(err);
            else {
                fs.mkdir(p, mode, cb);
            }
        });
    });
}

// Recursive rm.
function rm(filepath, callback) {
    var killswitch = false;
    fs.stat(filepath, function(err, stat) {
        if (err) return callback(err);
        if (stat.isFile()) return fs.unlink(filepath, callback);
        if (!stat.isDirectory()) return callback(new Error('Unrecognized file.'));
        Step(function() {
            fs.readdir(filepath, this);
        },
        function(err, files) {
            if (err) throw err;
            if (files.length === 0) return this(null, []);
            var group = this.group();
            _(files).each(function(file) {
                rm(path.join(filepath, file), group());
            });
        },
        function(err) {
            if (err) return callback(err);
            fs.rmdir(filepath, callback);
        });
    });
}

// Like fs.symlink except that it will overwrite stale symlinks at the
// given path if it exists.
function forcelink(linkdata, path, callback) {
    fs.lstat(path, function(err, stat) {
        // Error.
        if (err && err.code !== 'ENOENT')
            return callback(err);

        // Path does not exist. Symlink.
        if (err && err.code === 'ENOENT')
            return fs.symlink(linkdata, path, callback);

        // Path exists and is not a symlink. Do nothing.
        if (!stat.isSymbolicLink()) return callback();

        // Path exists and is a symlink. Check existing link path and update
        // if necessary.
        fs.readlink(path, function(err, old) {
            if (err) return callback(err);
            if (old === linkdata) return callback();
            fs.unlink(path, function(err) {
                if (err) return callback(err);
                fs.symlink(linkdata, path, callback);
            });
        });
    });
}

module.exports = {
    mkdirP: mkdirP,
    forcelink: forcelink,
    rm: rm
};

==> node-millstone_0.4.0.orig.tar.gz: package/lib/util.js <==
var fs = require('fs'),
    path = require('path'),
    _ = require('underscore'),
    Step = require('step'),
    mkdirP = require('mkdirp');

// Recursive rm.
function rm(filepath, callback) {
    var killswitch = false;
    fs.stat(filepath, function(err, stat) {
        if (err) return callback(err);
        if (stat.isFile()) return fs.unlink(filepath, callback);
        if (!stat.isDirectory()) return callback(new Error('Unrecognized file.'));
        Step(function() {
            fs.readdir(filepath, this);
        },
        function(err, files) {
            if (err) throw err;
            if (files.length === 0) return this(null, []);
            var group = this.group();
            _(files).each(function(file) {
                rm(path.join(filepath, file), group());
            });
        },
        function(err) {
            if (err) return callback(err);
            fs.rmdir(filepath, callback);
        });
    });
}

// Like fs.symlink except that it will overwrite stale symlinks at the
// given path if it exists.
function forcelink(linkdata, path, callback) {
    fs.lstat(path, function(err, stat) {
        // Error.
        if (err && err.code !== 'ENOENT')
            return callback(err);

        // Path does not exist. Symlink.
        if (err && err.code === 'ENOENT')
            return fs.symlink(linkdata, path, callback);

        // Path exists and is not a symlink. Do nothing.
        if (!stat.isSymbolicLink()) return callback();

        // Path exists and is a symlink. Check existing link path and update
        // if necessary.
        fs.readlink(path, function(err, old) {
            if (err) return callback(err);
            if (old === linkdata) return callback();
            fs.unlink(path, function(err) {
                if (err) return callback(err);
                fs.symlink(linkdata, path, callback);
            });
        });
    });
}

module.exports = {
    mkdirP: mkdirP,
    forcelink: forcelink,
    rm: rm
};
